@@ -1,11 +1,13 @@
 """
-Utils functions of ipfml package (array normalization)
+Utils functions of ipfml package (normalization, integral...)
 """
 
+# main imports
 import numpy as np
 import math
 import sys
 
+# computation imports
 from scipy.integrate import simps
 
 
@@ -22,31 +24,29 @@ def normalize_arr(arr):
 
     >>> from ipfml import utils
     >>> import numpy as np
-    >>> arr = np.arange(11)
+    >>> arr = np.arange(5)
     >>> arr_normalized = utils.normalize_arr(arr)
     >>> arr_normalized[1]
     0.1
     """
 
     output_arr = []
-    max_value = max(arr)
-    min_value = min(arr)
+    sum_value = sum(arr)
 
     for v in arr:
-        try:
-            output_arr.append((v - min_value) / (max_value - min_value))
-        except ZeroDivisionError:
-            output_arr.append((v - min_value) /
-                              (max_value - min_value + sys.float_info.epsilon))
+        # add of epsilon value in order to avoid Zero Division
+        output_arr.append(v / sum_value)
 
     return output_arr
 
 
-def normalize_arr_with_range(arr, min, max):
+def normalize_arr_with_range(arr, min_norm=None, max_norm=None):
     '''Normalize data of 1D array shape
 
     Args:
         arr: array data of 1D shape
+        min_norm: min expected value form normalization (default min found)
+        max_norm: max expected value form normalization (default max found)
 
     Returns:
         Normalized 1D Numpy array
@@ -63,11 +63,16 @@ def normalize_arr_with_range(arr, min, max):
 
     output_arr = []
 
+    if min_norm is None:
+        min_norm = min(arr)
+
+    if max_norm is None:
+        max_norm = max(arr)
+
     for v in arr:
-        try:
-            output_arr.append((v - min) / (max - min))
-        except ZeroDivisionError:
-            output_arr.append((v - min) / (max - min + sys.float_info.epsilon))
+        # add of epsilon value in order to avoid Zero Division
+        output_arr.append(
+            (v - min_norm) / (max_norm - min_norm + sys.float_info.epsilon))
 
     return output_arr
 
@@ -84,9 +89,10 @@ def normalize_2D_arr(arr):
     Example:
 
     >>> from PIL import Image
-    >>> from ipfml import utils, processing
+    >>> from ipfml import utils
+    >>> from ipfml.processing import transform
     >>> img = Image.open('./images/test_img.png')
-    >>> img_mscn = processing.rgb_to_mscn(img)
+    >>> img_mscn = transform.rgb_to_mscn(img)
     >>> img_normalized = utils.normalize_2D_arr(img_mscn)
     >>> img_normalized.shape
     (200, 200)
@@ -98,7 +104,7 @@ def normalize_2D_arr(arr):
 
     # normalize each row
     output_array = []
-    width, height = arr.shape
+    _, height = arr.shape
 
     for row_index in range(0, height):
         values = arr[row_index, :]
